==> bdgl-map-lib-1.2.0.tgz: package/public/markerCluster/poiData.js <==
const MYPOIS = [
    {
        "name": "梦圆宾馆(北京簋街店)",
        "location": {
            "lat": 39.946689,
            "lng": 116.43709
        },
        "address": "北京市东城区东直门内大街54号",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "251ef2782013eaeb3310af90",
        "detail": 1,
        "uid": "251ef2782013eaeb3310af90",
        "img": "/marker/bridge.gif"
    },
    {
        "name": "北京京鲁缘宾馆(北京站朝阳门南小街店)",
        "location": {
            "lat": 39.918287,
            "lng": 116.433861
        },
        "address": "朝阳门南小街5区22号楼地下一层1号",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "2938bddee92bfa1828201ab4",
        "telephone": "(010)65125088",
        "detail": 1,
        "uid": "2938bddee92bfa1828201ab4",
        "img": "/marker/bridge.gif"
    },
    {
        "name": "北京烽联宾馆",
        "location": {
            "lat": 39.908196,
            "lng": 116.421867
        },
        "address": "东交民巷8号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "fa01e93704767e53774ff178",
        "detail": 1,
        "uid": "fa01e93704767e53774ff178",
        "img": "/marker/event.gif"
    },
    {
        "name": "北京蓉驿致家酒店",
        "location": {
            "lat": 39.963548,
            "lng": 116.398973
        },
        "address": "安德里北街甲21号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "0eef2aa98ad4fa5c02ec013c",
        "telephone": "(010)62386688-6186",
        "detail": 1,
        "uid": "0eef2aa98ad4fa5c02ec013c",
        "img": "/marker/event.gif"
    },
    {
        "name": "和旭盛世宾馆(北京同仁医院北京站店)",
        "location": {
            "lat": 39.903841,
            "lng": 116.431251
        },
        "address": "崇文门国瑞东路39号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "6904b6626c87ce93725e801b",
        "telephone": "(010)67162585",
        "detail": 1,
        "uid": "6904b6626c87ce93725e801b",
        "img": "/marker/event.gif"
    },
    {
        "name": "平安府宾馆",
        "location": {
            "lat": 39.939662,
            "lng": 116.425685
        },
        "address": "北京市东城区平安大街东四十条100号",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "083a55fa89bee560246e9807",
        "detail": 1,
        "uid": "083a55fa89bee560246e9807",
        "img": "/marker/bridge.gif"
    },
    {
        "name": "北方朗悦酒店(北京鼓楼店)",
        "location": {
            "lat": 39.95815,
            "lng": 116.403493
        },
        "address": "安德路甲61号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "0c0b8d40b48d071d9d9d686c",
        "telephone": "(010)84133358",
        "detail": 1,
        "uid": "0c0b8d40b48d071d9d9d686c",
        "img": "/marker/event.gif"
    },
    {
        "name": "北京诺家宾馆",
        "location": {
            "lat": 39.903586,
            "lng": 116.43055
        },
        "address": "北京市东城区国瑞北路国瑞城中区14号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "",
        "telephone": "15117937536,18010190193",
        "detail": 1,
        "uid": "81334e515a0ef3abc6effb69",
        "img": "/marker/bridge.gif"
    },
    {
        "name": "北京碧水兰轩宾馆(协和医院店)",
        "location": {
            "lat": 39.919424,
            "lng": 116.43304
        },
        "address": "朝阳门内南小街385号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "e26dea96968b7a569cec2b11",
        "telephone": "18611540523",
        "detail": 1,
        "uid": "e26dea96968b7a569cec2b11",
        "img": "/marker/event.gif"
    },
    {
        "name": "嘉园之星(北京站店)",
        "location": {
            "lat": 39.895153,
            "lng": 116.436874
        },
        "address": "北京市东城区幸福大街甲39号5幢",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "",
        "telephone": "17710177588",
        "detail": 1,
        "uid": "4b739d14e57d94bad42ce255",
        "img": "/marker/bridge.gif"
    },
    {
        "name": "北京康泰福宾馆",
        "location": {
            "lat": 39.880386,
            "lng": 116.407584
        },
        "address": "北京市东城区永定门内大街140号天坛南里西区19号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "fa835ce23920bcafe812e45f",
        "telephone": "(010)67050108",
        "detail": 1,
        "uid": "fa835ce23920bcafe812e45f",
        "img": "/marker/event.gif"
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "uid": "e116be54e4214806c91b95d4",
        "img": "/marker/event.gif"
    },
    {
        "name": "博昊宾馆",
        "location": {
            "lat": 39.902826,
            "lng": 116.421138
        },
        "address": "北京市东兴隆街都市馨园solo2号楼(距同仁医院500米、新世界150米)",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "telephone": "18518275161",
        "detail": 1,
        "uid": "0a04131e55248ab3364aae19",
        "img": "/marker/bridge.gif"
    },
    {
        "name": "博昊宾馆2",
        "location": {
            "lat": 39.902826,
            "lng": 116.421138
        },
        "address": "北京市东兴隆街都市馨园solo2号楼(距同仁医院500米、新世界150米)",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "telephone": "18518275161",
        "detail": 1,
        "uid": "0a04131e55248ab3364aae18",
        "img": "/marker/event.gif"
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)1",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "uid": "e116be54e4214806c91b95d3",
        "img": "/marker/overSpeed.gif"
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)2",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "uid": "e116be54e4214806c91b95d2",
        "img": "/marker/event.gif"
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)3",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "uid": "e116be54e4214806c91b95d1",
        "img": "/marker/event.gif"
    },
    {
        "name": "北京成信宾馆(天坛店)",
        "location": {
            "lat": 39.88039,
            "lng": 116.426976
        },
        "address": "北京市东城区市东城区天坛东路77号天坛东里",
        "province": "北京市",
        "city": "北京市",
        "area": "其他",
        "street_id": "832489f9240f80c0a4c756b4",
        "detail": 1,
        "uid": "832489f9240f80c0a4c756b4",
        "img": "/marker/weather.gif"
    },
    {
        "name": "百时快捷酒店(北京天坛店)",
        "location": {
            "lat": 39.89339,
            "lng": 116.43329
        },
        "address": "北京市东城区法华寺街10号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "251374c9474cc926a11de901",
        "detail": 1,
        "uid": "251374c9474cc926a11de901",
        "img": "/marker/event.gif"
    },
    {
        "name": "北京花园宜成宾馆",
        "location": {
            "lat": 39.951802,
            "lng": 116.410459
        },
        "address": "北京市东城区车辇店胡同甲33号",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "c79a073ec09ab6ee72210ba7",
        "detail": 1,
        "uid": "c79a073ec09ab6ee72210ba7",
        "img": "/marker/overSpeed.gif"
    },
    {
        "name": "北京宝鼎中心酒店式公寓",
        "location": {
            "lat": 39.906218,
            "lng": 116.420544
        },
        "address": "北京市东城区东打磨厂街7号a座",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "e80284283dd5ddb48e77273a",
        "telephone": "18601157111",
        "detail": 1,
        "uid": "e80284283dd5ddb48e77273a",
        "img": "/marker/overSpeed.gif"
    },
    {
        "name": "首都宾馆-停车场",
        "location": {
            "lat": 39.907647,
            "lng": 116.415582
        },
        "address": "北京市东城区前门东大街3号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "detail": 1,
        "uid": "5ffb1816fb28e65e6e476087",
        "img": "/marker/event.gif"
    },
    {
        "name": "北京诺富特和平宾馆-停车场",
        "location": {
            "lat": 39.92204,
            "lng": 116.421612
        },
        "address": "北京市东城区金鱼胡同3号",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "",
        "detail": 1,
        "uid": "cc8aa959befbfa53a8175a13",
        "img": "/marker/overSpeed.gif"
    }
];

==> bdgl-map-lib-1.3.0.tgz: package/public/markerCluster/poiData.js <==
const MYPOIS = [
    {
        "name": "梦圆宾馆(北京簋街店)", // 必选（设置提示文字，字段可自定义）
        "location": {
            "lat": 39.946689,
            "lng": 116.43709
        }, // // 必选（格式固定）
        "address": "北京市东城区东直门内大街54号",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区", // 必选（用于区分类型，字段可自定义）
        "street_id": "251ef2782013eaeb3310af90",
        "detail": 1,
        "id": "251ef2782013eaeb3310af90", // 必选（字段固定，设置唯一值）
        "img": "/marker/bridge.gif", // 必须（字段固定，设置初始图标）
        "chooseImg": "/marker/checkpoint.png", // 可选（字段固定，设置点击替换的图标）
    },
    {
        "name": "北京京鲁缘宾馆(北京站朝阳门南小街店)",
        "location": {
            "lat": 39.918287,
            "lng": 116.433861
        },
        "address": "朝阳门南小街5区22号楼地下一层1号",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "2938bddee92bfa1828201ab4",
        "telephone": "(010)65125088",
        "detail": 1,
        "id": "2938bddee92bfa1828201ab4",
        "img": "/marker/bridge.gif",
        "chooseImg": "/marker/checkpoint.png",
    },
    {
        "name": "北京烽联宾馆",
        "location": {
            "lat": 39.908196,
            "lng": 116.421867
        },
        "address": "东交民巷8号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "fa01e93704767e53774ff178",
        "detail": 1,
        "id": "fa01e93704767e53774ff178",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "北京蓉驿致家酒店",
        "location": {
            "lat": 39.963548,
            "lng": 116.398973
        },
        "address": "安德里北街甲21号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "0eef2aa98ad4fa5c02ec013c",
        "telephone": "(010)62386688-6186",
        "detail": 1,
        "id": "0eef2aa98ad4fa5c02ec013c",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "和旭盛世宾馆(北京同仁医院北京站店)",
        "location": {
            "lat": 39.903841,
            "lng": 116.431251
        },
        "address": "崇文门国瑞东路39号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "6904b6626c87ce93725e801b",
        "telephone": "(010)67162585",
        "detail": 1,
        "id": "6904b6626c87ce93725e801b",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "平安府宾馆",
        "location": {
            "lat": 39.939662,
            "lng": 116.425685
        },
        "address": "北京市东城区平安大街东四十条100号",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "083a55fa89bee560246e9807",
        "detail": 1,
        "id": "083a55fa89bee560246e9807",
        "img": "/marker/bridge.gif",
        "chooseImg": "/marker/checkpoint.png",
    },
    {
        "name": "北方朗悦酒店(北京鼓楼店)",
        "location": {
            "lat": 39.95815,
            "lng": 116.403493
        },
        "address": "安德路甲61号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "0c0b8d40b48d071d9d9d686c",
        "telephone": "(010)84133358",
        "detail": 1,
        "id": "0c0b8d40b48d071d9d9d686c",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "北京诺家宾馆",
        "location": {
            "lat": 39.903586,
            "lng": 116.43055
        },
        "address": "北京市东城区国瑞北路国瑞城中区14号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "",
        "telephone": "15117937536,18010190193",
        "detail": 1,
        "id": "81334e515a0ef3abc6effb69",
        "img": "/marker/bridge.gif",
        "chooseImg": "/marker/checkpoint.png",
    },
    {
        "name": "北京碧水兰轩宾馆(协和医院店)",
        "location": {
            "lat": 39.919424,
            "lng": 116.43304
        },
        "address": "朝阳门内南小街385号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "e26dea96968b7a569cec2b11",
        "telephone": "18611540523",
        "detail": 1,
        "id": "e26dea96968b7a569cec2b11",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "嘉园之星(北京站店)",
        "location": {
            "lat": 39.895153,
            "lng": 116.436874
        },
        "address": "北京市东城区幸福大街甲39号5幢",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "street_id": "",
        "telephone": "17710177588",
        "detail": 1,
        "id": "4b739d14e57d94bad42ce255",
        "img": "/marker/bridge.gif",
        "chooseImg": "/marker/checkpoint.png",
    },
    {
        "name": "北京康泰福宾馆",
        "location": {
            "lat": 39.880386,
            "lng": 116.407584
        },
        "address": "北京市东城区永定门内大街140号天坛南里西区19号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "fa835ce23920bcafe812e45f",
        "telephone": "(010)67050108",
        "detail": 1,
        "id": "fa835ce23920bcafe812e45f",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "id": "e116be54e4214806c91b95d4",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "博昊宾馆",
        "location": {
            "lat": 39.902826,
            "lng": 116.421138
        },
        "address": "北京市东兴隆街都市馨园solo2号楼(距同仁医院500米、新世界150米)",
        "province": "北京市",
        "city": "北京市",
        "area": "老城区",
        "telephone": "18518275161",
        "detail": 1,
        "id": "0a04131e55248ab3364aae19",
        "img": "/marker/bridge.gif",
        "chooseImg": "/marker/checkpoint.png",
    },
    {
        "name": "博昊宾馆2",
        "location": {
            "lat": 39.902826,
            "lng": 116.421138
        },
        "address": "北京市东兴隆街都市馨园solo2号楼(距同仁医院500米、新世界150米)",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "telephone": "18518275161",
        "detail": 1,
        "id": "0a04131e55248ab3364aae18",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)1",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "id": "e116be54e4214806c91b95d3",
        "img": "/marker/overSpeed.gif",
        "chooseImg": "/marker/start_point.png",
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)2",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "id": "e116be54e4214806c91b95d2",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "宏昌盛达酒店(北京南站永定门外地铁站店)3",
        "location": {
            "lat": 39.871676,
            "lng": 116.396943
        },
        "address": "革新南路西革新里110号院5号楼",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "telephone": "(010)67237939",
        "detail": 1,
        "id": "e116be54e4214806c91b95d1",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "北京成信宾馆(天坛店)",
        "location": {
            "lat": 39.88039,
            "lng": 116.426976
        },
        "address": "北京市东城区市东城区天坛东路77号天坛东里",
        "province": "北京市",
        "city": "北京市",
        "area": "其他",
        "street_id": "832489f9240f80c0a4c756b4",
        "detail": 1,
        "id": "832489f9240f80c0a4c756b4",
        "img": "/marker/weather.gif",
        "chooseImg": "/marker/weather_sunny.png",
    },
    {
        "name": "百时快捷酒店(北京天坛店)",
        "location": {
            "lat": 39.89339,
            "lng": 116.43329
        },
        "address": "北京市东城区法华寺街10号",
        "province": "北京市",
        "city": "北京市",
        "area": "其他",
        "street_id": "251374c9474cc926a11de901",
        "detail": 1,
        "id": "251374c9474cc926a11de901",
        "img": "/marker/weather.gif",
        "chooseImg": "/marker/weather_sunny.png",
    },
    {
        "name": "北京花园宜成宾馆",
        "location": {
            "lat": 39.951802,
            "lng": 116.410459
        },
        "address": "北京市东城区车辇店胡同甲33号",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "c79a073ec09ab6ee72210ba7",
        "detail": 1,
        "id": "c79a073ec09ab6ee72210ba7",
        "img": "/marker/overSpeed.gif",
        "chooseImg": "/marker/start_point.png",
    },
    {
        "name": "北京宝鼎中心酒店式公寓",
        "location": {
            "lat": 39.906218,
            "lng": 116.420544
        },
        "address": "北京市东城区东打磨厂街7号a座",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "e80284283dd5ddb48e77273a",
        "telephone": "18601157111",
        "detail": 1,
        "id": "e80284283dd5ddb48e77273a",
        "img": "/marker/overSpeed.gif",
        "chooseImg": "/marker/start_point.png",
    },
    {
        "name": "首都宾馆-停车场",
        "location": {
            "lat": 39.907647,
            "lng": 116.415582
        },
        "address": "北京市东城区前门东大街3号",
        "province": "北京市",
        "city": "北京市",
        "area": "东城区",
        "street_id": "",
        "detail": 1,
        "id": "5ffb1816fb28e65e6e476087",
        "img": "/marker/warning_marker.png",
        "chooseImg": "/marker/warning_marker_choose.png",
    },
    {
        "name": "北京诺富特和平宾馆-停车场",
        "location": {
            "lat": 39.92204,
            "lng": 116.421612
        },
        "address": "北京市东城区金鱼胡同3号",
        "province": "北京市",
        "city": "北京市",
        "area": "西城区",
        "street_id": "",
        "detail": 1,
        "id": "cc8aa959befbfa53a8175a13",
        "img": "/marker/overSpeed.gif",
        "chooseImg": "/marker/start_point.png",
    }
];

export default MYPOIS
